dnl @* PATCH_LIBTOOL_CHANGING_CMDS_IFS
dnl
dnl Do a `grep "^[a-z]*_cmds=" libtool` - these are "subroutines"
dnl encoded by libtool.m4 into the generated libtool script. Since
dnl libtool assumes that there is no subroutine-facility in the
dnl shell invoked, these are not actually subroutines, but actually
dnl a "list of commands". This looks correct, but the command
dnl separator is not ";" - it is "~", the tilde character.
dnl
dnl Now, grep again, look for `grep 'IFS="~"' libtool` and see 
dnl that libtool scripting uses a for-loop on the command-list,
dnl i.e for cmd in $some_cmds. This works correctly when the
dnl IFS was modified, where IFS stands for "input field separator"
dnl which is whitespace characters by default.
dnl
dnl The problem: I have some real-world filesystems where there
dnl are directories using "~" inside of them, to be more to the
dnl point, it is a change control management software that uses
dnl source repositories of the form "path/master/project~version/src"
dnl and libtool has the tendency to resolve any symlinks so that
dnl it will paste such path into the $_cmds script when it gets
dnl evaluated a number of times.
dnl
dnl This script is a workaround: I do not know why the ";" was
dnl not chosen as the IFS, perhaps it has some weird interactions
dnl in some shells since it is also the default record separator
dnl being one time bigger in context than the argument separator.
dnl I have made good success however with using "?" as the IFS,
dnl since there is no path-name that uses a question mark, and 
dnl there is no _cmds ever around that uses "?" for some thing.
dnl
dnl Oh yes, there are some usages of "*" to match shell-wise at 
dnl the output file of some tool, so that might have triggered
dnl the choice to not use "?" in the first place - but in real
dnl life it never occured that a _cmds script was created that
dnl has gone to use "?". And so, this ac-macro exchanges the
dnl s/~/?/g in configured _cmds variables and replaces all
dnl occurences of s/IFS="~"/IFS="?"/ - and it all works smooth now.
dnl
dnl @= guidod@gmx.de
dnl @$Id: patch_libtool_changing_cmds_ifs.m4,v 1.3 2003/03/25 20:04:40 guidod Exp $

AC_DEFUN([PATCH_LIBTOOL_CHANGING_CMDS_IFS],
[# patch libtool to change $_cmds IFS from ~ to ? character
if grep "^[[_$as_cr_letters]]_cmds=.*[[?]]" libtool >/dev/null; then
  AC_MSG_WARN(dnl
  [patching libtool skipped - _cmds already contain question marks])
else
 AC_MSG_RESULT([patching libtool to change cmds IFS from ~ to ?])
    test -f libtool.old || (mv libtool libtool.old && cp libtool.old libtool)
    sed -e "/^[[_$as_cr_letters]]*_cmds=/s/~/?/g" -e 's/IFS="~"/IFS="?"/g' \
        -e "s/IFS='~'/IFS='?'/g"    libtool > libtool.new
    (test -s libtool.new || rm libtool.new) 2>/dev/null
    test -f libtool.new && mv libtool.new libtool # not 2>/dev/null !!
    test -f libtool     || mv libtool.old libtool
fi
])
