dnl @* PATCH_LIBTOOL_TO_ADD_HOST_CC
dnl
dnl The libtool 1.4.x processing (and patched 1.3.5) uses a little
dnl "impgen" tool to turn a "*.dll" into an import "*.lib" as it is
dnl needed for win32 targets. However, this little tool is not shipped
dnl by binutils, it is not even a command option of dlltool or dllwrap.
dnl It happens to be a C source snippet implanted into the libtool
dnl sources - it gets written to ".libs", compiled into a binary 
dnl on-the-fly, and executed right away on the "dll" file to create
dnl the import-lib (dll.a files in gcc-speak).
dnl
dnl This mode works fine for a native build within mingw or cygwin,
dnl but it does not work in cross-compile mode since CC is a
dnl crosscompiler - it will create an .exe file on a non-win32
dnl system, and as a result an impgen.exe is created on-the-fly
dnl that can not be executed on-the-fly. Luckily, the actual
dnl libtool snippet uses HOST_CC to compile the sources which
dnl has a fallback to CC when the HOST_CC variable was not set.
dnl
dnl this ac-macro is trying to detect a valid HOST_CC which is not
dnl a cross-compiler. This is done by looking into the $PATH for
dnl a "cc" and the result is patched into libtool a HOST_CC, iow
dnl it adds another configured variable at the top of the libtool
dnl script.
dnl
dnl In discussions on the libtool mailinglist it occurred that
dnl later gcc/binutils generations are able to link with dlls 
dnl directly, i.e. there is no import-lib needed anymore. The
dnl import-table is created within the linker itself (in-memory)
dnl and bound to the .exe/.dll currently in the making. The
dnl whole stuff of impgen exe and compiling it on-the-fly, well,
dnl it is superflouos then. 
dnl
dnl Since mingw crosscompilers tend to be quite a fresh development
dnl it was agreed to remove the impgen stuff completly from
dnl libtool sources. Still however, this macro does not hurt
dnl since it does not patch impgen cmds but it just adds HOST_CC
dnl which might be useful in other cross-compiling cases as well.
dnl Therefore, you can leave it in for maximum compatibility and
dnl portability.
dnl
dnl @= guidod@gmx.de
dnl @$Id: patch_libtool_to_add_host_cc.m4,v 1.3 2003/03/23 13:20:27 guidod Exp $

AC_DEFUN([PATCH_LIBTOOL_TO_ADD_HOST_CC],
[# patch libtool to add HOST_CC sometimes needed in crosscompiling a win32 dll
if grep "HOST_CC" libtool >/dev/null; then
  if test "$build" != "$host" ; then
    if test "_$HOST_CC" = "_" ; then
      HOST_CC="false"
      for i in `echo $PATH | sed 's,:, ,g'` ; do
      test -x $i/cc && HOST_CC=$i/cc
      done
    fi
AC_MSG_RESULT(patching libtool to add HOST_CC=$HOST_CC)
    test -f libtool.old || (mv libtool libtool.old && cp libtool.old libtool)
    sed -e "/BEGIN.*LIBTOOL.*CONFIG/a\\
HOST_CC=$HOST_CC" libtool >libtool.new
    (test -s libtool.new || rm libtool.new) 2>/dev/null
    test -f libtool.new && mv libtool.new libtool # not 2>/dev/null !!
    test -f libtool     || mv libtool.old libtool
  fi
fi
])
